SyncApplier

Struct SyncApplier 

pub struct SyncApplier<T, F>
where T: Clone + Send + Sync + 'static, F: Fn(T) -> Result<(), String> + Send + Sync + 'static,
{ /* private fields */ }
Convenience wrapper for synchronous appliers. Most appliers just set an atomic or reconfigure a rate limiter and have no genuine async work to do — this wrapper lifts a plain Fn(T) -> Result<(), String> into a ControlApplier<T>.

Implementations

Source

impl<T, F> SyncApplier<T, F>
where T: Clone + Send + Sync + 'static, F: Fn(T) -> Result<(), String> + Send + Sync + 'static,

pub fn new(f: F) -> Self