pub struct ThreadPools { /* private fields */ }Expand description
Process-wide registry. Owns the resolved config and applies each pool’s scheduling policy at thread spawn.
Implementations
Sourceimpl ThreadPools
impl ThreadPools
pub fn config(&self) -> &ThreadPoolConfig
Sourcepub fn spawn(
&self,
pool: &str,
name: &str,
f: impl FnOnce() + Send + 'static,
) -> Result<JoinHandle<()>, String>
pub fn spawn( &self, pool: &str, name: &str, f: impl FnOnce() + Send + 'static, ) -> Result<JoinHandle<()>, String>
Spawn a thread on a named pool with that pool’s scheduling policy applied
from inside the new thread (the syscalls target the calling thread).
The achieved policy is logged once at thread start. Err on an unknown
pool name.
Sourcepub fn spawn_timing(
&self,
name: &str,
f: impl FnOnce() + Send + 'static,
) -> Result<JoinHandle<()>, String>
pub fn spawn_timing( &self, name: &str, f: impl FnOnce() + Send + 'static, ) -> Result<JoinHandle<()>, String>
Convenience for the cadence scheduler.